@@ -1,9 +1,10 @@
 import cssutils
 import logging
+
 cssutils.log.setLevel(logging.FATAL)
 
 
-css = '''@import "example.css"; 
+css = r'''@import "example.css";
 a {
     color: blue !important;
     c\olor: green !important;
@@ -21,7 +22,7 @@ print(repr(cssutils.ser.prefs))
 print("\nCSS Serialized")
 print(sheet.cssText)
 
-print("\nCSS Serialized with ``keepAllProperties`` = False") 
+print("\nCSS Serialized with ``keepAllProperties`` = False")
 cssutils.ser.prefs.keepAllProperties = False
 print(sheet.cssText)
 
@@ -39,13 +40,15 @@ print('     name and results in actual value only:')
 print('\t.getPropertyValue("color") ==', end=' ')
 print(sheet.cssRules[1].style.getPropertyValue('color'))
 print('\t.getPropertyValue("c\\olor") ==', end=' ')
-print(sheet.cssRules[1].style.getPropertyValue('c\olor'))
+print(sheet.cssRules[1].style.getPropertyValue(r'c\olor'))
 print('\t.getPropertyValue("c\\o\\l\\o\\r") ==', end=' ')
 print(sheet.cssRules[1].style.getPropertyValue('c\\o\\l\\o\\r'))
-print() 
+print()
 
-print('\nCSS Serialized with indent = 2*" ", importHrefFormat="string", lineNumbers=True')
-cssutils.ser.prefs.indent = 2*' '
+print(
+    '\nCSS Serialized with indent = 2*" ", importHrefFormat="string", lineNumbers=True'
+)
+cssutils.ser.prefs.indent = 2 * ' '
 # used to set indentation string, default is 4*' '
 cssutils.ser.prefs.importHrefFormat = 'string'
 # or 'uri', defaults to the format used in parsed stylesheet
@@ -57,7 +60,7 @@ cssutils.ser.prefs.useMinified()
 print(sheet.cssText)
 
 # OUTPUTS
-#1: @import "example.css";
-#2: body {
-#3:   color: red
-#4:   }
+# 1: @import "example.css";
+# 2: body {
+# 3:   color: red
+# 4:   }
